Class: Atatus::Config Private
- Inherits:
-
Object
- Object
- Atatus::Config
- Extended by:
- Options, Deprecations
- Defined in:
- lib/atatus/config.rb,
lib/atatus/config/bytes.rb,
lib/atatus/config/options.rb,
lib/atatus/config/duration.rb,
lib/atatus/config/regexp_list.rb,
lib/atatus/config/round_float.rb,
lib/atatus/config/server_info.rb,
lib/atatus/config/log_level_map.rb,
lib/atatus/config/error_limit_converter.rb,
lib/atatus/config/wildcard_pattern_list.rb
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Defined Under Namespace
Modules: Options Classes: Bytes, Duration, ErrorLimitConverter, LogLevelMap, RegexpList, RoundFloat, ServerInfo, WildcardPatternList
Constant Summary collapse
- SANITIZE_FIELD_NAMES_DEFAULT =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
%w[password passwd pwd secret *key *token* *session* *credit* *card* *auth* set-cookie].freeze
Instance Attribute Summary collapse
- #__root_path ⇒ Object private
- #__view_paths ⇒ Object private
- #logger ⇒ Object private
- #options ⇒ Object readonly private
Instance Method Summary collapse
- #app=(app) ⇒ Object private
- #assign(update) ⇒ Object private
- #available_instrumentations ⇒ Object private
- #collect_metrics? ⇒ Boolean private
- #enabled_instrumentations ⇒ Object private
-
#initialize(options = {}) {|_self| ... } ⇒ Config
constructor
private
rubocop:enable Layout/LineLength, Layout/ExtraSpacing.
- #inspect ⇒ Object private
- #log_ecs_formatting ⇒ Object private
- #log_ecs_formatting=(value) ⇒ Object private
- #replace_options(new_options) ⇒ Object private
- #span_frames_min_duration=(value) ⇒ Object private
- #span_frames_min_duration? ⇒ Boolean private
- #span_frames_min_duration_us ⇒ Object private
- #ssl_context ⇒ Object private
- #use_ssl? ⇒ Boolean private
- #version ⇒ Object private
Methods included from Options
Methods included from Deprecations
Constructor Details
#initialize(options = {}) {|_self| ... } ⇒ Config
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
rubocop:enable Layout/LineLength, Layout/ExtraSpacing
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/atatus/config.rb', line 131 def initialize( = {}) @options = load_schema assign() # Pick out config_file specifically as we need it now to load it, # but still need the other env vars to have precedence env = load_env if (env_config_file = env.delete(:config_file)) self.config_file = env_config_file end assign(load_config_file(self.environment)) assign(env) yield self if block_given? if self.logger.nil? || self.log_path self.logger = build_logger end @__view_paths ||= [] @__root_path ||= Dir.pwd self.filter_exception_types = self.get_ignore_exceptions(:sinatra) end |
Instance Attribute Details
#__root_path ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
158 159 160 |
# File 'lib/atatus/config.rb', line 158 def __root_path @__root_path end |
#__view_paths ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
158 159 160 |
# File 'lib/atatus/config.rb', line 158 def __view_paths @__view_paths end |
#logger ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
158 159 160 |
# File 'lib/atatus/config.rb', line 158 def logger @logger end |
#options ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
160 161 162 |
# File 'lib/atatus/config.rb', line 160 def @options end |
Instance Method Details
#app=(app) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
209 210 211 212 213 214 215 216 217 218 |
# File 'lib/atatus/config.rb', line 209 def app=(app) case app_type?(app) when :sinatra set_sinatra(app) when :rails set_rails(app) else self.service_name = 'ruby' end end |
#assign(update) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
162 163 164 165 |
# File 'lib/atatus/config.rb', line 162 def assign(update) return unless update update.each { |key, value| send(:"#{key}=", value) } end |
#available_instrumentations ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/atatus/config.rb', line 167 def available_instrumentations %w[ action_dispatch azure_storage_table delayed_job dynamo_db elasticsearch faraday http json mongo net_http rake racecar redis resque s3 sequel shoryuken sidekiq sinatra sneakers sns sqs sucker_punch tilt ] end |
#collect_metrics? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
224 225 226 |
# File 'lib/atatus/config.rb', line 224 def collect_metrics? metrics_interval > 0 end |
#enabled_instrumentations ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
196 197 198 |
# File 'lib/atatus/config.rb', line 196 def enabled_instrumentations available_instrumentations - disable_instrumentations end |
#inspect ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
262 263 264 |
# File 'lib/atatus/config.rb', line 262 def inspect super.split.first + '>' end |
#log_ecs_formatting ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
120 121 122 |
# File 'lib/atatus/config.rb', line 120 def log_ecs_formatting log_ecs_reformatting end |
#log_ecs_formatting=(value) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
124 125 126 |
# File 'lib/atatus/config.rb', line 124 def log_ecs_formatting=(value) @options[:log_ecs_reformatting].set(value) end |
#replace_options(new_options) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
200 201 202 203 204 205 206 207 |
# File 'lib/atatus/config.rb', line 200 def () return if .nil? || .empty? = @options.dup .each do |key, value| .fetch(key.to_sym).set(value) end @options = end |
#span_frames_min_duration=(value) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
232 233 234 235 |
# File 'lib/atatus/config.rb', line 232 def span_frames_min_duration=(value) super @span_frames_min_duration_us = nil end |
#span_frames_min_duration? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
228 229 230 |
# File 'lib/atatus/config.rb', line 228 def span_frames_min_duration? span_frames_min_duration != 0 end |
#span_frames_min_duration_us ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
237 238 239 |
# File 'lib/atatus/config.rb', line 237 def span_frames_min_duration_us @span_frames_min_duration_us ||= span_frames_min_duration * 1_000_000 end |
#ssl_context ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/atatus/config.rb', line 241 def ssl_context return unless use_ssl? @ssl_context ||= OpenSSL::SSL::SSLContext.new.tap do |context| if server_ca_cert_file context.ca_file = server_ca_cert_file else context.cert_store = OpenSSL::X509::Store.new.tap(&:set_default_paths) end context.verify_mode = if verify_server_cert OpenSSL::SSL::VERIFY_PEER else OpenSSL::SSL::VERIFY_NONE end end end |
#use_ssl? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
220 221 222 |
# File 'lib/atatus/config.rb', line 220 def use_ssl? server_url.start_with?('https') end |
#version ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
266 267 268 |
# File 'lib/atatus/config.rb', line 266 def version @version ||= ServerInfo.new(self).version end |